hello

package module
v0.0.0-...-e90d727 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 20, 2020 License: MIT Imports: 3 Imported by: 0

README

hello-world

Testing GitHub Actions for Golang

GitHub Actions status

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Hello

func Hello() string

Types

This section is empty.

Directories

Path Synopsis
Package morestrings implements additional functions to manipulate UTF-8 encoded strings, beyond what is provided in the standard "strings" package.
Package morestrings implements additional functions to manipulate UTF-8 encoded strings, beyond what is provided in the standard "strings" package.

Jump to